@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: edit.php,v 1.16 2013/01/01 20:46:27 gruberroland Exp $
+$Id: edit.php 4888 2013-05-01 12:36:17Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Tilo Lutz
-                2005 - 2012  Roland Gruber
+                2005 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -86,6 +86,10 @@ else if (count($_POST)==0) {
 		logNewMessage(LOG_ERR, 'User tried to access hidden account type: ' . $type);
 		die();
 	}
+	elseif (!checkIfNewEntriesAreAllowed($type)) {
+		logNewMessage(LOG_ERR, 'User tried to create entry of forbidden account type: ' . $type);
+		die();
+	}
 	$_SESSION['account'] = new accountContainer($type, 'account');
 	$_SESSION['account']->new_account();
 }
