@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmain.php,v 1.139 2012/11/02 18:15:17 gruberroland Exp $
+$Id: confmain.php 4841 2013-04-02 18:54:39Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2012  Roland Gruber
@@ -144,7 +144,7 @@ foreach ($cssFiles as $cssEntry) {
 
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 echo ("</head>\n");
-echo ("<body onload=\"configLoginMethodChanged()\">\n");
+echo ("<body>\n");
 // include all JavaScript files
 $jsDirName = dirname(__FILE__) . '/../lib';
 $jsDir = dir($jsDirName);
@@ -222,13 +222,13 @@ echo '</ul>';
 
 <script type="text/javascript">
 jQuery(document).ready(function() {
-	jQuery('#generalSettingsButton').addClass('ui-tabs-selected');
+	jQuery('#generalSettingsButton').addClass('ui-tabs-active');
 	jQuery('#generalSettingsButton').addClass('ui-state-active');
-	jQuery('#generalSettingsButton').addClass('userlist-bright');
+	jQuery('#generalSettingsButton').addClass('user-bright');
 });
 </script>
 
-<div class="ui-tabs-panel ui-widget-content ui-corner-bottom userlist-bright">
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom user-bright">
 <?php
 
 $container = new htmlTable();
@@ -398,7 +398,14 @@ $loginOptions = array(
 );
 $loginSelect = new htmlTableExtendedSelect('loginMethod', $loginOptions, array($conf->getLoginMethod()), _("Login method"), '220');
 $loginSelect->setHasDescriptiveElements(true);
-$loginSelect->setOnchangeEvent('configLoginMethodChanged()');
+$loginSelect->setTableRowsToHide(array(
+	LAMConfig::LOGIN_LIST => array('loginSearchSuffix', 'loginSearchFilter', 'loginSearchDN', 'loginSearchPassword', 'httpAuthentication'),
+	LAMConfig::LOGIN_SEARCH => array('admins')
+));
+$loginSelect->setTableRowsToShow(array(
+	LAMConfig::LOGIN_LIST => array('admins'),
+	LAMConfig::LOGIN_SEARCH => array('loginSearchSuffix', 'loginSearchFilter', 'loginSearchDN', 'loginSearchPassword', 'httpAuthentication')
+));
 $securitySettingsContent->addElement($loginSelect, true);
 // admin list
 $adminText = implode("\n", explode(";", $conf->get_Adminstring()));
