@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: confmodules.php,v 1.47 2012/11/02 18:15:17 gruberroland Exp $
+$Id: confmodules.php 4841 2013-04-02 18:54:39Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2012  Roland Gruber
@@ -181,9 +181,9 @@ echo '</ul>';
 
 <script type="text/javascript">
 jQuery(document).ready(function() {
-	jQuery('#editmodules').addClass('ui-tabs-selected');
+	jQuery('#editmodules').addClass('ui-tabs-active');
 	jQuery('#editmodules').addClass('ui-state-active');
-	jQuery('#editmodules').addClass('userlist-bright');
+	jQuery('#editmodules').addClass('user-bright');
 	// set common width for select boxes
 	var maxWidth = 0;
 	jQuery("select").each(function(){
@@ -194,7 +194,7 @@ jQuery(document).ready(function() {
 });
 </script>
 
-<div class="ui-tabs-panel ui-widget-content ui-corner-bottom userlist-bright">
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom user-bright">
 <?php
 
 
