@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: moduleSettings.php,v 1.18 2012/11/25 10:55:54 gruberroland Exp $
+$Id: moduleSettings.php 4906 2013-05-09 19:10:35Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2009 - 2012  Roland Gruber
@@ -180,13 +180,13 @@ echo '</ul>';
 
 <script type="text/javascript">
 jQuery(document).ready(function() {
-	jQuery('#moduleSettings').addClass('ui-tabs-selected');
+	jQuery('#moduleSettings').addClass('ui-tabs-active');
 	jQuery('#moduleSettings').addClass('ui-state-active');
-	jQuery('#moduleSettings').addClass('userlist-bright');
+	jQuery('#moduleSettings').addClass('user-bright');
 });
 </script>
 
-<div class="ui-tabs-panel ui-widget-content ui-corner-bottom userlist-bright">
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom user-bright">
 <?php
 
 
@@ -212,9 +212,9 @@ $modules = array_keys($options);
 $_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
 	if (sizeof($options[$modules[$i]]) < 1) continue;
-	echo "<fieldset class=\"ui-corner-all useredit\">\n";
+	echo "<fieldset class=\"ui-corner-all user-border user-bright\">\n";
 	$icon = '';
-	$module = new $modules[$i]('none');
+	$module = moduleCache::getModule($modules[$i], 'none');
 	$iconImage = $module->getIcon();
 	if ($iconImage != null) {
 		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
