@@ -1,6 +1,6 @@
 <?php
 /*
-	$Id: delete.php,v 1.89 2012/06/05 18:20:17 gruberroland Exp $
+	$Id: delete.php 4906 2013-05-09 19:10:35Z gruberroland $
 
 	This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 	Copyright (C) 2003 - 2006  Tilo Lutz
@@ -72,6 +72,10 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 		logNewMessage(LOG_ERR, 'Invalid type: ' . $_GET['type']);
 		die();
 	}
+	if (!checkIfDeleteEntriesIsAllowed($_GET['type'])) {
+		logNewMessage(LOG_ERR, 'User tried to delete entries of forbidden type '. $_GET['type']);
+		die();
+	}
 	// Create account list
 	foreach ($_SESSION['delete_dn'] as $dn) {
 		$start = strpos ($dn, "=")+1;
@@ -83,7 +87,7 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	$_SESSION['account'] = new accountContainer($_GET['type'], 'account');
 	// Show HTML Page
 	include 'main_header.php';
-	echo "<div class=\"".$_GET['type']."list-bright smallPaddingContent\">";
+	echo "<div class=\"".$_GET['type']."-bright smallPaddingContent\">";
 	echo "<br>\n";
 	echo "<form action=\"delete.php\" method=\"post\">\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_GET['type'] . "\">\n";
@@ -108,7 +112,7 @@ if (isset($_GET['type']) && isset($_SESSION['delete_dn'])) {
 	$values = array();
 	$tabindex = 100;
 	foreach ($modules as $module) {
-		$module = new $module($_GET['type']);
+		$module = moduleCache::getModule($module, $_GET['type']);
 		parseHtml(get_class($module), $module->display_html_delete(), $values, true, $tabindex, $_GET['type']);
 	}
 	echo "</table>\n";
@@ -138,11 +142,15 @@ elseif (isset($_POST['cancelAllOk'])) {
 }
 
 if (isset($_POST['delete'])) {
+	if (!checkIfDeleteEntriesIsAllowed($_POST['type'])) {
+		logNewMessage(LOG_ERR, 'User tried to delete entries of forbidden type '. $_POST['type']);
+		die();
+	}
 	// Show HTML Page
 	include 'main_header.php';
 	echo "<form action=\"delete.php\" method=\"post\">\n";
 	echo "<input name=\"type\" type=\"hidden\" value=\"" . $_POST['type'] . "\">\n";
-	echo "<div class=\"".$_POST['type']."list-bright smallPaddingContent\"><br>\n";
+	echo "<div class=\"".$_POST['type']."-bright smallPaddingContent\"><br>\n";
 	echo "<br>\n";
 	
 	// Delete dns
