@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: 141_jquery-validationEngine-lang.php,v 1.3 2012/10/21 13:31:25 gruberroland Exp $
+$Id: 141_jquery-validationEngine-lang.php 4764 2013-02-22 19:30:43Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2010         Cedric Dugas and Olivier Refalo
-                2011 - 2012  Roland Gruber
+                2011 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,19 @@ $Id: 141_jquery-validationEngine-lang.php,v 1.3 2012/10/21 13:31:25 gruberroland
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
+
+/** access to configuration options */
+include_once("../../lib/config.inc"); // Include config.inc which provides Config class
+
+// set session save path
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path(dirname(__FILE__) . '/../../sess');
+}
+
+// start empty session and change ID for security reasons
+@session_start();
+setlanguage();
+
 ?>
 
 (function($){
