@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: login.php,v 1.158 2013/01/05 16:22:58 gruberroland Exp $
+$Id: login.php 4934 2013-05-25 13:24:55Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -57,9 +57,11 @@ session_destroy();
 session_start();
 session_regenerate_id(true);
 
+$profiles = getConfigProfiles();
+
 // save last selected login profile
 if(isset($_GET['useProfile'])) {
-	if (in_array($_GET['useProfile'], getConfigProfiles())) {
+	if (in_array($_GET['useProfile'], $profiles)) {
 		setcookie("lam_default_profile", $_GET['useProfile'], time() + 365*60*60*24);
 	}
 	else {
@@ -71,18 +73,29 @@ if(isset($_GET['useProfile'])) {
 $default_Config = new LAMCfgMain();
 $_SESSION["cfgMain"] = $default_Config;
 $default_Profile = $default_Config->default;
-if(isset($_COOKIE["lam_default_profile"]) && in_array($_COOKIE["lam_default_profile"], getConfigProfiles())) {
+if(isset($_COOKIE["lam_default_profile"]) && in_array($_COOKIE["lam_default_profile"], $profiles)) {
 	$default_Profile = $_COOKIE["lam_default_profile"];
 }
 // Reload loginpage after a profile change
-if(isset($_GET['useProfile'])) {
+if(isset($_GET['useProfile']) && in_array($_GET['useProfile'], $profiles)) {
 	logNewMessage(LOG_DEBUG, "Change server profile to " . $_GET['useProfile']);
 	$_SESSION['config'] = new LAMConfig($_GET['useProfile']); // Recreate the config object with the submited
 }
 // Load login page
-elseif (!empty($default_Profile)) {
+elseif (!empty($default_Profile) && in_array($default_Profile, $profiles)) {
 	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
 }
+else if (sizeof($profiles) > 0) {
+	// use first profile as fallback
+	$_SESSION["config"] = new LAMConfig($profiles[0]);
+}
+else {
+	$_SESSION["config"] = null;
+}
+
+if (!isset($default_Config->default) || !in_array($default_Config->default, $profiles)) {
+	$error_message = _('No default profile set. Please set it in the server profile configuration.');
+}
 
 if (!empty($_SESSION["config"])) {
 	$_SESSION['language'] = $_SESSION["config"]->get_defaultLanguage();
@@ -198,19 +211,19 @@ function display_LoginPage($config_object) {
 		    StatusMessage('ERROR', 'Unable to migrate configuration files. Please allow write access to these paths:', implode('<br>', $result));
 		}
 		else {
-			upgradeConfigToServerProfileFolders(getConfigProfiles());
+			upgradeConfigToServerProfileFolders($profiles);
 			StatusMessage('INFO', 'Config file migration finished.');
 		}
 	}
 	// copy any missing default profiles
-	copyConfigTemplates(getConfigProfiles());
+	copyConfigTemplates($profiles);
 	
 	// set focus on password field
 	if (!empty($config_object)) {
 		echo "<script type=\"text/javascript\" language=\"javascript\">\n";
 		echo "<!--\n";
 		echo "function focusLogin() {\n";
-		if ($config_object->getLoginMethod() == LAMConfig::LOGIN_LIST) {
+		if (($config_object->getLoginMethod() == LAMConfig::LOGIN_LIST) || isset($_COOKIE['lam_login_name'])) {
 			echo "myElement = document.getElementsByName('passwd')[0];\n";
 			echo "myElement.focus();\n";
 		}
@@ -268,6 +281,9 @@ function display_LoginPage($config_object) {
 				}
 			}
 		}
+		else {
+			StatusMessage('WARN', _('Please enter the configuration and create a server profile.'));
+		}
 		// check if session expired
 		if (isset($_GET['expired'])) {
 			StatusMessage("ERROR", _("Your session expired, please log in again."));
@@ -320,9 +336,18 @@ function display_LoginPage($config_object) {
 								for($i = 0; $i < count($admins); $i++) {
 									$text = explode(",", $admins[$i]);
 									$text = explode("=", $text[0]);
-									$adminList[$text[1]] = $admins[$i];
+									if (isset($text[1])) {
+										$adminList[$text[1]] = $admins[$i];
+									}
+									else {
+										$adminList[$text[0]] = $admins[$i];
+									}
 								}
-								$userSelect = new htmlSelect('username', $adminList);
+								$selectedAdmin = array();
+								if (isset($_POST['username']) && in_array($_POST['username'], $adminList)) {
+									$selectedAdmin = array($_POST['username']);
+								}
+								$userSelect = new htmlSelect('username', $adminList, $selectedAdmin);
 								$userSelect->setHasDescriptiveElements(true);
 								$userSelect->alignment = htmlElement::ALIGN_LEFT;
 								$table->addElement($userSelect);
@@ -334,7 +359,11 @@ function display_LoginPage($config_object) {
 									$table->addElement($httpAuth);
 								}
 								else {
-									$userInput = new htmlInputField('username');
+									$user = '';
+									if (isset($_COOKIE["lam_login_name"])) {
+										$user = $_COOKIE["lam_login_name"];
+									}
+									$userInput = new htmlInputField('username', $user);
 									$userInput->alignment = htmlElement::ALIGN_LEFT;
 									$table->addElement($userInput);
 								}
@@ -375,6 +404,22 @@ function display_LoginPage($config_object) {
 							$languageSelect->setHasDescriptiveElements(true);
 							$languageSelect->alignment = htmlElement::ALIGN_LEFT;
 							$table->addElement($languageSelect, true);
+							// remember login user
+							if (($config_object->getLoginMethod() == LAMConfig::LOGIN_SEARCH) && !($config_object->getHttpAuthentication() == 'true')) {
+								$rememberLabel = new htmlOutputText('');
+								$rememberLabel->alignment = htmlElement::ALIGN_RIGHT;
+								$table->addElement($rememberLabel);
+								$table->addElement($gap);
+								$rememberGroup = new htmlGroup();
+								$doRemember = false;
+								if (isset($_COOKIE["lam_login_name"])) {
+									$doRemember = true;
+								}
+								$rememberGroup->addElement(new htmlInputCheckbox('rememberLogin', $doRemember));
+								$rememberGroup->addElement(new htmlSpacer('1px', null));
+								$rememberGroup->addElement(new htmlOutputText(_('Remember user name')));
+								$table->addElement($rememberGroup, true);
+							}
 							// login button
 							$table->addElement(new htmlSpacer(null, '35px'));
 							$table->addElement(new htmlHiddenInput('checklogin', 'checklogin'));
@@ -480,6 +525,12 @@ if(!empty($_POST['checklogin'])) {
 		$password = $_SERVER['PHP_AUTH_PW'];
 	}
 	else {
+		if (isset($_POST['rememberLogin']) && ($_POST['rememberLogin'] == 'on')) {
+			setcookie('lam_login_name', $_POST['username'], time() + 60*60*24*365);
+		}
+		else if (isset($_COOKIE['lam_login_name']) && ($_SESSION['config']->getLoginMethod() == LAMConfig::LOGIN_SEARCH)) {
+			setcookie('lam_login_name', '', time() + 60*60*24*365);
+		}
 		if($_POST['passwd'] == "") {
 			logNewMessage(LOG_DEBUG, "Empty password for login");
 			$error_message = _("Empty password submitted. Please try again.");
