@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.29 2013/01/01 20:46:28 gruberroland Exp $
+$Id: massBuildAccounts.php 4888 2013-05-01 12:36:17Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2012  Roland Gruber
+  Copyright (C) 2004 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -97,8 +97,14 @@ if (isAccountTypeHidden($scope)) {
 	logNewMessage(LOG_ERR, 'User tried to access hidden upload: ' . $scope);
 	die();
 }
+if (!checkIfNewEntriesAreAllowed($scope)) {
+	logNewMessage(LOG_ERR, 'User tried to access forbidden upload: ' . $scope);
+	die();
+}
 
-echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
+echo '<form enctype="multipart/form-data" action="masscreate.php" method="post">';
+echo '<div class="' . $scope . '-bright smallPaddingContent">';
+$container = new htmlTable();
 
 $selectedModules = explode(',', $_POST['selectedModules']);
 if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
@@ -161,15 +167,25 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 			}
 			$values_unique = array_unique($values_given);
 			if (sizeof($values_given) != sizeof($values_unique)) {
-				$errors[] = array(_("This column is defined to include unique entries but duplicates were found:"), $columns[$i]['name']);
+				$duplicates = array();
+				foreach ($values_given as $key => $value) {
+					if (!isset($values_unique[$key])) {
+						$duplicates[] = htmlspecialchars($value);
+					}
+				}
+				$duplicates = array_values(array_unique($duplicates));
+				$errors[] = array(_("This column is defined to include unique entries but duplicates were found:") . ' ' . $columns[$i]['name'], implode(', ', $duplicates));
 			}
 		}
 	}
 	
 	// if input data is invalid just display error messages (max 50)
 	if (sizeof($errors) > 0) {
-		for ($i = 0; $i < sizeof($errors); $i++) StatusMessage("ERROR", $errors[$i][0], $errors[$i][1]);
-		massPrintBackButton($scope, $selectedModules);
+		for ($i = 0; $i < sizeof($errors); $i++) {
+			$container->addElement(new htmlStatusMessage("ERROR", $errors[$i][0], $errors[$i][1]), true);
+		}
+		$container->addElement(new htmlSpacer(null, '10px'), true);
+		massPrintBackButton($scope, $selectedModules, $container);
 	}
 	
 	// let modules build accounts
@@ -193,7 +209,9 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 			}
 			// print errors if DN could not be built
 			if (sizeof($errors) > 0) {
-				for ($i = 0; $i < sizeof($errors); $i++) StatusMessage("ERROR", $errors[$i][0], $errors[$i][1], $errors[$i][2]);
+				for ($i = 0; $i < sizeof($errors); $i++) {
+					$container->addElement(new htmlStatusMessage("ERROR", $errors[$i][0], $errors[$i][1], $errors[$i][2]), true);
+				}
 			}
 			else {
 				// store accounts in session
@@ -218,34 +236,33 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 					$_SESSION['mass_pdf']['structure'] = null;
 				}
 				// show links for upload and LDIF export
-				echo "<div class=\"title\">\n";
-				echo "<h2 class=\"titleText\">" . _("LAM has checked your input and is now ready to create the accounts.") . "</h2>\n";
-				echo "</div>";
-				echo "<p>&nbsp;</p>\n";
-				echo "<a id=\"uploadLink\" href=\"massDoUpload.php\">" . _("Upload accounts to LDAP") . "</a>";
-				echo "&nbsp;&nbsp;&nbsp;&nbsp;";
-				echo "<a id=\"createLDIFLink\" href=\"massBuildAccounts.php?showldif=true\">" . _("Show LDIF file") . "</a>";
-				?>
-				<script type="text/javascript">
-				jQuery(document).ready(function() {
-					jQuery('#uploadLink').button();
-					jQuery('#createLDIFLink').button();
-				});
-				</script>
-				<?php
+				$container->addElement(new htmlTitle(_("LAM has checked your input and is now ready to create the accounts.")), true);
+				$container->addElement(new htmlSpacer(null, '10px'), true);
+				$buttonContainer = new htmlTable();
+				$buttonContainer->addElement(new htmlLink(_("Upload accounts to LDAP"), 'massDoUpload.php', '../graphics/up.gif', true));
+				$buttonContainer->addElement(new htmlLink(_("Show LDIF file"), 'massBuildAccounts.php?showldif=true', '../graphics/edit.png', true));
+				$buttonContainer->addElement(new htmlSpacer('10px', null));
+				massPrintBackButton($scope, $selectedModules, $buttonContainer);
+				$container->addElement($buttonContainer, true);
 			}
 		}
 		else {
-			massPrintBackButton($scope, $selectedModules);
+			$container->addElement(new htmlSpacer(null, '10px'), true);
+			massPrintBackButton($scope, $selectedModules, $container);
 		}
 	}
 }
 else {
-	StatusMessage('ERROR', _('Please provide a file to upload.'));
-	massPrintBackButton($scope, $selectedModules);
+	$container->addElement(new htmlStatusMessage('ERROR', _('Please provide a file to upload.')), true);
+	$container->addElement(new htmlSpacer(null, '10px'), true);
+	massPrintBackButton($scope, $selectedModules, $container);
 }
 
+$tabindex = 1;
+parseHtml(null, $container, array(), false, $tabindex, $scope);
+
 echo '</div>';
+echo '</form>';
 include 'main_footer.php';
 
 /**
@@ -253,12 +270,12 @@ include 'main_footer.php';
  *
  * @param String $scope account type (e.g. user)
  * @param array $selectedModules selected modules for upload
+ * @param htmlTable $container table container
  */
-function massPrintBackButton($scope, $selectedModules) {
-	echo '<form enctype="multipart/form-data" action="masscreate.php" method="post">';
-	$container = new htmlTable();
-	$container->addElement(new htmlSpacer(null, '10px'), true);
-	$container->addElement(new htmlButton('submit', _('Back')));
+function massPrintBackButton($scope, $selectedModules, &$container) {
+	$backButton = new htmlButton('submit', _('Back'));
+	$backButton->setIconClass('backButton');
+	$container->addElement($backButton);
 	$container->addElement(new htmlHiddenInput('type', $scope));
 	$createPDF = 0;
 	if (isset($_POST['createPDF']) && ($_POST['createPDF'] == 'on')) {
@@ -269,9 +286,6 @@ function massPrintBackButton($scope, $selectedModules) {
 	for ($i = 0; $i < sizeof($selectedModules); $i++) {
 		$container->addElement(new htmlHiddenInput($scope . '_' . $selectedModules[$i], 'on'));
 	}
-	$tabindex = 1;
-	parseHtml(null, $container, array(), false, $tabindex, $scope);
-	echo '</form>';
 }
 
 ?>
\ No newline at end of file
