@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.33 2013/01/01 20:46:28 gruberroland Exp $
+$Id: massDoUpload.php 4888 2013-05-01 12:36:17Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2012  Roland Gruber
+  Copyright (C) 2004 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -68,8 +68,12 @@ if (isAccountTypeHidden($scope)) {
 	logNewMessage(LOG_ERR, 'User tried to access hidden upload: ' . $scope);
 	die();
 }
+if (!checkIfNewEntriesAreAllowed($scope)) {
+	logNewMessage(LOG_ERR, 'User tried to access forbidden upload: ' . $scope);
+	die();
+}
 
-echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
+echo '<div class="' . $scope . '-bright smallPaddingContent">';
 
 // create accounts
 $accounts = unserialize($_SESSION['ldap']->decrypt($_SESSION['mass_accounts']));
