@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: masscreate.php,v 1.105 2013/01/01 20:46:28 gruberroland Exp $
+$Id: masscreate.php 4906 2013-05-09 19:10:35Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2012  Roland Gruber
+  Copyright (C) 2004 - 2013  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -78,9 +78,10 @@ include 'main_header.php';
 
 // get possible types and remove those which do not support file upload
 $types = $_SESSION['config']->get_ActiveTypes();
-for ($i = 0; $i < sizeof($types); $i++) {
+$count = sizeof($types);
+for ($i = 0; $i < $count; $i++) {
 	$myType = new $types[$i]();
-	if (!$myType->supportsFileUpload() || isAccountTypeHidden($types[$i])) {
+	if (!$myType->supportsFileUpload() || isAccountTypeHidden($types[$i]) || !checkIfNewEntriesAreAllowed($types[$i])) {
 		unset($types[$i]);
 	}
 }
@@ -118,7 +119,7 @@ $divClass = 'user';
 if (isset($_REQUEST['type'])) {
 	$divClass = $_REQUEST['type'];
 }
-echo '<div class="' . $divClass . 'list-bright smallPaddingContent">';
+echo '<div class="' . $divClass . '-bright smallPaddingContent">';
 echo "<div class=\"title\">\n";
 echo "<h2 class=\"titleText\">" . _("Account creation via file upload") . "</h2>\n";
 echo "</div>";
@@ -169,7 +170,7 @@ for ($i = 0; $i < sizeof($types); $i++) {
 		if (($m != 0) && ($m%3 == 0)) {
 			echo $innerTable->addNewLine();
 		}
-		$module = new $modules[$m]($types[$i]);
+		$module = moduleCache::getModule($modules[$m], $types[$i]);
 		$iconImage = '../graphics/' . $module->getIcon();
 		$innerTable->addElement(new htmlImage($iconImage));
 		$enabled = true;
@@ -225,7 +226,7 @@ include 'main_footer.php';
 * @param array $selectedModules list of selected account modules
 */
 function showMainPage($scope, $selectedModules) {
-	echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
+	echo '<div class="' . $scope . '-bright smallPaddingContent">';
 	// get input fields from modules
 	$columns = getUploadColumns($scope, $selectedModules);
 	$modules = array_keys($columns);
@@ -267,14 +268,16 @@ function showMainPage($scope, $selectedModules) {
 	}
 	$inputContainer->addElement(new htmlTableExtendedSelect('pdfStructure', $pdfStructures, $pdfSelected, _('PDF structure')), true);
 	$inputContainer->addElement(new htmlSpacer(null, '5px'), true);
-	$inputContainer->addElement(new htmlButton('submitfile', _('Upload file and create accounts')));
+	$uploadButton = new htmlButton('submitfile', _('Upload file and create accounts'));
+	$uploadButton->setIconClass('upButton');
+	$inputContainer->addElement($uploadButton);
 	$container->addElement($inputContainer, true);
 	$container->addElement(new htmlSpacer(null, '10px'), true);
 	// column list
 	$columnSpacer = new htmlSpacer('10px', null);
 	$container->addElement(new htmlTitle(_("Columns")), true);
 	$columnContainer = new htmlTable();
-	$columnContainer->setCSSClasses(array($scope . 'list'));
+	$columnContainer->setCSSClasses(array($scope . 'list', 'collapse'));
 	// DN options
 	$dnTitle = new htmlSubTitle(_("DN settings"), '../graphics/logo32.png');
 	$dnTitle->colspan = 20;
@@ -316,7 +319,7 @@ function showMainPage($scope, $selectedModules) {
 	$dnSuffixRowCells[] = new htmlOutputText('');
 	$dnSuffixRowCells[] = new htmlSpacer(null, '25px');
 	$dnSuffixRow = new htmlTableRow($dnSuffixRowCells);
-	$dnSuffixRow->setCSSClasses(array($scope . 'list-dark'));
+	$dnSuffixRow->setCSSClasses(array($scope . '-dark'));
 	$columnContainer->addElement($dnSuffixRow);
 	$dnRDNRowCells = array();
 	$dnRDNRowCells[] = $columnSpacer;
@@ -336,7 +339,7 @@ function showMainPage($scope, $selectedModules) {
 	$dnRDNRowCells[] = new htmlOutputText(implode(", ", $rdnAttributes));
 	$dnRDNRowCells[] = new htmlSpacer(null, '25px');
 	$dnRDNRow = new htmlTableRow($dnRDNRowCells);
-	$dnRDNRow->setCSSClasses(array($scope . 'list-bright'));
+	$dnRDNRow->setCSSClasses(array($scope . '-bright'));
 	$columnContainer->addElement($dnRDNRow);
 	// module options
 	for ($m = 0; $m < sizeof($modules); $m++) {
@@ -346,7 +349,7 @@ function showMainPage($scope, $selectedModules) {
 		}
 		$columnContainer->addElement(new htmlSpacer(null, '10px'), true);
 		$icon = '';
-		$module = new $modules[$m]($scope);
+		$module = moduleCache::getModule($modules[$m], $scope);
 		$iconImage = $module->getIcon();
 		if ($iconImage != null) {
 			$icon = '../graphics/' . $iconImage;
@@ -415,10 +418,10 @@ function showMainPage($scope, $selectedModules) {
 			$rowCells[] = new htmlSpacer(null, '25px');
 			$row = new htmlTableRow($rowCells);
 			if ($odd) {
-				$row->setCSSClasses(array($scope . 'list-dark'));
+				$row->setCSSClasses(array($scope . '-dark'));
 			}
 			else {
-				$row->setCSSClasses(array($scope . 'list-bright'));
+				$row->setCSSClasses(array($scope . '-bright'));
 			}
 			$odd = !$odd;
 			$columnContainer->addElement($row);
